//
//  ViewController.m
//  DynamicUIButton
//
/*Copyright (c) 2012 Brandon McQuilkin
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 
 The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#import "ViewController.h"

@interface ViewController (){
int timesClicked;
}
@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    [self setup];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) {
        return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
    } else {
        return YES;
    }
}

- (void)setup
{
    //Create a dictionary for all button parameters, all prameters are passed to the button with this dictionary.
    theParameters = [[NSMutableDictionary alloc] init];
    //Setup of button parameters
    //First create a dictionary with the parameters for each state. Each state has two parameters, its tint (UIColor) and title (NSString). If one is missing, the program will fill it in with the default parameter. Even though the button will try to fix missing parameters, it is best practice to set it up completly each time.
    //Use the provided keys to input the data.
    
    //Inital State: Only Requiered State, if left nil, the button will use default parameters.
    NSDictionary *initialStateDict = [[NSDictionary alloc] initWithObjectsAndKeys:[UIColor colorWithRed:0.239 green:0.241 blue:0.914 alpha:1], kDBParameterTintKey,
                                      @"Save", kDBParameterTitleKey, nil];
    //Confirm State: Optional, button will skip state if nil. Tap again to confirm action.
    NSDictionary *confirmStateDict = [[NSDictionary alloc] initWithObjectsAndKeys:[UIColor colorWithRed:0.439 green:0.741 blue:0.314 alpha:1], kDBParameterTintKey,
                                      @"Are you sure?", kDBParameterTitleKey, nil];
    //Processing State: Optional, button will skip this state, and the success/failure states if nil. You exit this state by preforming changeButtonToState: at the end of the preformed action
    NSDictionary *processingStateDict = [[NSDictionary alloc] initWithObjectsAndKeys:[UIColor colorWithWhite:0.5 alpha:1], kDBParameterTintKey,
                                      @"Saving...", kDBParameterTitleKey, nil];
    //Success State: Optional, you must manually set the button to this state. After a period of time (defaullt .5 sec), the button will transition to the initial state or the disabled state.
    NSDictionary *successStateDict = [[NSDictionary alloc] initWithObjectsAndKeys:[UIColor colorWithRed:0.000 green:0.502 blue:0.000 alpha:1], kDBParameterTintKey,
                                         @"Success ✓", kDBParameterTitleKey, nil];
    //Failure State: Optional, you must manually set the button to this state. After a period of time (defaullt .5 sec), the button will transition to the initial state or the disabled state.
    NSDictionary *failureStateDict = [[NSDictionary alloc] initWithObjectsAndKeys:[UIColor colorWithRed:0.694 green:0.184 blue:0.196 alpha:1], kDBParameterTintKey,
                                      @"Failure ✗", kDBParameterTitleKey, nil];
    //Disabled State: Optional, only set this if you want the button to be one shot. Once the button has been disabled, you can return it to its initial state with changeButtonToState:. If not set the button will loop back to its initial state each time.
    NSDictionary *disabledStateDict = [[NSDictionary alloc] initWithObjectsAndKeys:[UIColor colorWithWhite:0.85 alpha:1], kDBParameterTintKey,
                                      @"DISABLED", kDBParameterTitleKey, nil];
    
    //Add States to dictionary: 
    [theParameters setObject:initialStateDict forKey:kDBStateInitial];
    [theParameters setObject:confirmStateDict forKey:kDBStateConfirm];
    [theParameters setObject:processingStateDict forKey:kDBStateProcess];
    [theParameters setObject:successStateDict forKey:kDBStateSuccess];
    [theParameters setObject:failureStateDict forKey:kDBStateFailure];
    //[theParameters setObject:disabledStateDict forKey:kDBStateDisabled]; //Uncomment if you want the button to be one shot
    
    //Other Button Parameters:
    //Animation Type: The button's width will change to fit the text provided. The button can expand to the left, right, or center
    [theParameters setObject:kDBToggleLeft forKey:kDBToggleStyleKey];
    //Font Name: The font name you would like to use. (the same font name when creating a UIFont), size will be auto calculated.
    [theParameters setObject:@"Courier-Bold" forKey:kDBFontNameKey];
    //Icon: An icon to be displaied to the left of the text: will be scaled down to match the button size.
    [theParameters setObject:[UIImage imageNamed:@"saveIcon.png"] forKey:kDBIconKey];
    
    //Now Create the button, The button's size is based on the height of the button. The width value of the frame will be ignored. Also the button only works for an action for UIControlEventTouchUpInside.
    
    //Full Loop 
    DynamicButton *button = [[DynamicButton alloc] initWithParameters:theParameters andFrame:CGRectMake(self.view.frame.size.width /2.0, 10, 0, 50)];
    [button addTarget:self action:@selector(changeButtonSaved:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:button];

    
    //counter
    timesClicked = 0;
    
}

- (IBAction)changeButtonSaved:(id)sender
{
    timesClicked += 1;
    DynamicButton *button = (DynamicButton *)sender;
    //If you try and force change button to state, to a state that is nil, weird things will happen.
    if ([theParameters objectForKey:kDBStateSuccess] != nil && [theParameters objectForKey:kDBStateFailure] != nil) {
        if (timesClicked %2) {
            [button performSelector:@selector(changeButtonToState:) withObject:kDBStateSuccess afterDelay:5.0];
        } else {
            [button performSelector:@selector(changeButtonToState:) withObject:kDBStateFailure afterDelay:5.0];
        }
    } else {
        [button performSelector:@selector(changeButtonToState:) withObject:kDBStateInitial afterDelay:5.0];
    }
}

@end
